@@ -41,6 +41,13 @@ sub DBC {
     return $DBH=$dbh;
 }
 
+sub db_check {
+  my ($self,$dbh)=@_;
+  return 0 unless defined($DBH);
+  return 0 unless $DBH eq $dbh;
+  return 1;
+}
+
 # This method runs after the new constructor
 sub BUILD {
   my ($self)=@_;
@@ -50,6 +57,7 @@ sub BUILD {
       name=>"database_connection_lost",
       code=>sub { 
 	my ($dbh)=@_;
+          return unless $self->db_check($dbh);
           $self->reset_session;
         }
       )
@@ -59,6 +67,7 @@ sub BUILD {
       name=>"database_error",
       code=>sub { 
 	my ($err,$dbh)=@_;
+          return unless $self->db_check($dbh);
           $self->reset_session;
       }
     )
